@@ -67,6 +67,8 @@
 #endif
 
 #include <glom/filechooser_export.h>
+#include <gtkmm/stock.h>
+#include <gtkmm/radioaction.h>
 #include <libglom/privs.h>
 #include <libglom/db_utils.h>
 #include <sstream> //For stringstream.
