@@ -20,6 +20,8 @@
  */
 
 #include "csv_parser.h"
+#include <glibmm/convert.h>
+#include <glibmm/main.h>
 
 #include <cerrno>
 #include <iostream>
@@ -56,6 +58,7 @@ CsvParser::CsvParser(const std::string& encoding_charset)
 : m_raw(0),
   m_encoding(encoding_charset),
   m_input_position(0),
+  m_in_quotes(false),
   m_idle_connection(),
   m_line_number(0),
   m_state(STATE_NONE),
@@ -247,8 +250,6 @@ Glib::ustring::const_iterator CsvParser::advance_field(const Glib::ustring::cons
       {
         break;
       }
-
-      continue;
     }
 
     field += c; // Just so that we don't need to iterate through the field again, since there is no Glib::ustring::substr(iter, iter)
@@ -266,6 +267,8 @@ void CsvParser::clear()
   //m_stream.reset();
   //m_raw.clear();
   m_rows.clear();
+  m_in_quotes = false;
+
   // Set to current encoding I guess ...
   //m_conv("UTF-8", encoding),
   m_input_position= 0;
@@ -334,7 +337,6 @@ bool CsvParser::on_idle_parse()
   // Identify the record rows in the .csv file.
   // We can't just search for newlines because they may be inside quotes too. 
   // TODO: Use a regex instead, to more easily handle quotes?
-  bool in_quotes = false;
   while(true)
   {
     //std::cout << "debug: checking start: " << std::string(prev, 10) << std::endl;
@@ -372,14 +374,14 @@ bool CsvParser::on_idle_parse()
       signal_encoding_error().emit();
       return false;  //Stop calling the idle handler.
     }
-    else if(in_quotes)
+    else if(m_in_quotes)
     {
       // Ignore newlines inside quotes.
 
       // End quote:
       if(ch == (char)QUOTE)
       {
-        in_quotes = false;
+        m_in_quotes = false;
 
         /*
         const size_t len = pos - prev;
@@ -400,7 +402,7 @@ bool CsvParser::on_idle_parse()
       // Start quote:
       if(ch == (char)QUOTE)
       {
-        in_quotes = true;
+        m_in_quotes = true;
         prev = pos + 1;
         continue;
       }
