@@ -27,6 +27,9 @@
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/cellrenderercombo.h>
 #include <glom/utils_ui.h>
+#include <gtkmm/main.h>
+#include <glibmm/convert.h>
+#include <glibmm/markup.h>
 #include <glibmm/i18n.h>
 #include <cerrno>
 #include <iostream>
