@@ -29,6 +29,8 @@
 #include <libglom/connectionpool_backends/postgres_self.h>
 # include <libglom/connectionpool_backends/sqlite.h>
 
+#include <glibmm/main.h>
+
 #ifdef G_OS_WIN32
 # include <windows.h>
 #else
@@ -38,6 +40,8 @@
 
 #include <signal.h> //To catch segfaults
 
+#include <glibmm/convert.h>
+#include <glibmm/miscutils.h>
 #include <glibmm/i18n.h>
 
 #include <iostream>
@@ -208,7 +212,13 @@ const ConnectionPool::Backend* ConnectionPool::get_backend() const
   return m_backend.get();
 }
 
-
+bool ConnectionPool::get_backend_supports_cursor() const
+{
+  //TODO: Is there a generic libgda way to discover this?
+  const ConnectionPoolBackends::Sqlite* sqlite_backend =
+    dynamic_cast<const ConnectionPoolBackends::Sqlite*>(get_backend());
+  return !sqlite_backend;
+}
 
 //static:
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
@@ -514,7 +524,7 @@ const FieldTypes* ConnectionPool::get_field_types() const
   return m_pFieldTypes;
 }
 
-Glib::ustring ConnectionPool::get_string_find_operator() const
+Gnome::Gda::SqlOperatorType ConnectionPool::get_string_find_operator() const
 {
   g_assert(m_backend.get());
   return m_backend->get_string_find_operator();
