@@ -21,13 +21,19 @@
 #include <libglom/connectionpool_backends/postgres_self.h>
 #include <libglom/utils.h>
 #include <libglom/spawn_with_feedback.h>
-#include <giomm.h>
+#include <giomm/file.h>
 #include <glib/gstdio.h> // For g_remove
 
+#include <glibmm/convert.h>
+#include <glibmm/miscutils.h>
+#include <glibmm/stringutils.h>
+#include <glibmm/regex.h>
+#include <glibmm/main.h>
 #include <glibmm/i18n.h>
 
 #include <libglom/gst-package.h>
 #include <sstream> //For stringstream
+#include <iostream>
 
 #ifdef G_OS_WIN32
 # include <windows.h>
@@ -120,7 +126,7 @@ bool PostgresSelfHosted::get_self_hosting_active() const
   return m_port != 0;
 }
 
-int PostgresSelfHosted::get_port() const
+unsigned int PostgresSelfHosted::get_port() const
 {
   return m_port;
 }
@@ -265,7 +271,7 @@ Glib::ustring PostgresSelfHosted::get_postgresql_utils_version(const SlotProgres
   Glib::RefPtr<Glib::Regex> regex;
 
   //We want the characters at the end:
-  const gchar* VERSION_REGEX = "pg_ctl \\(PostgreSQL\\) (.*)";
+  const gchar VERSION_REGEX[] = "pg_ctl \\(PostgreSQL\\) (.*)";
 
   #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
@@ -317,7 +323,7 @@ float PostgresSelfHosted::get_postgresql_utils_version_as_number(const SlotProgr
   Glib::RefPtr<Glib::Regex> regex;
 
   //We want the characters at the end:
-  const gchar* VERSION_REGEX = "^(\\d*)\\.(\\d*)";
+  const gchar VERSION_REGEX[] = "^(\\d*)\\.(\\d*)";
 
   #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
@@ -423,7 +429,7 @@ Backend::StartupErrors PostgresSelfHosted::startup(const SlotProgress& slot_prog
   set_network_shared(slot_progress, m_network_shared); //Creates pg_hba.conf and pg_ident.conf
 
 
-  const int available_port = discover_first_free_port(PORT_POSTGRESQL_SELF_HOSTED_START, PORT_POSTGRESQL_SELF_HOSTED_END);
+  const unsigned int available_port = discover_first_free_port(PORT_POSTGRESQL_SELF_HOSTED_START, PORT_POSTGRESQL_SELF_HOSTED_END);
   //std::cout << "ConnectionPool::create_self_hosting():() : debug: Available port for self-hosting: " << available_port << std::endl;
   if(available_port == 0)
   {
@@ -625,7 +631,7 @@ bool PostgresSelfHosted::create_database(const Glib::ustring& database_name, con
   return attempt_create_database(database_name, m_host, port_as_string(m_port), username, password, error);
 }
 
-int PostgresSelfHosted::discover_first_free_port(int start_port, int end_port)
+unsigned int PostgresSelfHosted::discover_first_free_port(unsigned int start_port, unsigned int end_port)
 {
   //Open a socket so we can try to bind it to a port:
   const int fd = socket(AF_INET, SOCK_STREAM, 0);
@@ -645,7 +651,7 @@ int PostgresSelfHosted::discover_first_free_port(int start_port, int end_port)
   memset(&sa, 0, sizeof(sa));
   sa.sin_family = AF_INET;
 
-  int port_to_try = start_port;
+  guint16 port_to_try = start_port;
   while (port_to_try <= end_port)
   {
     sa.sin_port = htons(port_to_try);
