@@ -23,6 +23,8 @@
 #include <libglom/connectionpool_backends/sqlite.h>
 
 #include <giomm/file.h>
+#include <libgdamm/metastore.h>
+#include <libgdamm/config.h>
 
 #include <iostream>
 
