@@ -26,6 +26,8 @@
 #include <libglom/data_structure/parameternamegenerator.h>
 #include <libglom/utils.h>
 #include <libgdamm/value.h>
+#include <libgdamm/metastore.h>
+#include <glibmm/timer.h>
 #include <libgda/libgda.h> // For gda_g_type_from_string
 #include <glibmm/i18n.h>
 #include <iostream>
@@ -1374,12 +1376,46 @@ bool drop_column(const Glib::ustring& table_name, const Glib::ustring& field_nam
   return true;
 }
 
+static void builder_set_where_autoincrement(const Glib::RefPtr<Gnome::Gda::SqlBuilder>& builder, const Glib::ustring& table_name, const Glib::ustring& field_name)
+{
+  if(table_name.empty())
+  {
+    std::cerr << G_STRFUNC << ": table_name is empty" << std::endl;
+    return;
+  }
+  
+  if(field_name.empty())
+  {
+    std::cerr << G_STRFUNC << ": field_name is empty" << std::endl;
+    return;
+  }
+  
+  builder->set_where(builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_AND,
+    builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
+      builder->add_field_id(GLOM_STANDARD_TABLE_AUTOINCREMENTS_FIELD_TABLE_NAME, GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME),
+      builder->add_expr(table_name)),
+    builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
+      builder->add_field_id(GLOM_STANDARD_TABLE_AUTOINCREMENTS_FIELD_FIELD_NAME, GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME),
+      builder->add_expr(field_name))));
+}
+
 Gnome::Gda::Value get_next_auto_increment_value(const Glib::ustring& table_name, const Glib::ustring& field_name)
 {
+  if(table_name.empty())
+  {
+    std::cerr << G_STRFUNC << ": table_name is empty" << std::endl;
+    return Gnome::Gda::Value();
+  }
+  
+  if(field_name.empty())
+  {
+    std::cerr << G_STRFUNC << ": field_name is empty" << std::endl;
+    return Gnome::Gda::Value();
+  }
+  
   const Gnome::Gda::Value result = DbUtils::auto_increment_insert_first_if_necessary(table_name, field_name);
   double num_result = Conversions::get_double_for_gda_value_numeric(result);
 
-
   //Increment the next_value:
   ++num_result;
   const Gnome::Gda::Value next_value = Conversions::parse_value(num_result);
@@ -1387,13 +1423,8 @@ Gnome::Gda::Value get_next_auto_increment_value(const Glib::ustring& table_name,
   Glib::RefPtr<Gnome::Gda::SqlBuilder> builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_UPDATE);
   builder->set_table(GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME);
   builder->add_field_value_as_value(GLOM_STANDARD_TABLE_AUTOINCREMENTS_FIELD_NEXT_VALUE, next_value);
-  builder->set_where(builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_AND,
-                                       builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
-                                                         builder->add_field_id(GLOM_STANDARD_TABLE_AUTOINCREMENTS_FIELD_TABLE_NAME, GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME),
-                                                         builder->add_expr(table_name)),
-                                       builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
-                                                         builder->add_field_id(GLOM_STANDARD_TABLE_AUTOINCREMENTS_FIELD_FIELD_NAME, GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME),
-                                                         builder->add_expr(field_name))));
+  builder_set_where_autoincrement(builder, table_name, field_name);
+
   const bool test = query_execute(builder);
   if(!test)
     std::cerr << "get_next_auto_increment_value(): Increment failed." << std::endl;
@@ -1403,6 +1434,18 @@ Gnome::Gda::Value get_next_auto_increment_value(const Glib::ustring& table_name,
 
 Gnome::Gda::Value auto_increment_insert_first_if_necessary(const Glib::ustring& table_name, const Glib::ustring& field_name)
 {
+  if(table_name.empty())
+  {
+    std::cerr << G_STRFUNC << ": table_name is empty" << std::endl;
+    return Gnome::Gda::Value();
+  }
+  
+  if(field_name.empty())
+  {
+    std::cerr << G_STRFUNC << ": field_name is empty" << std::endl;
+    return Gnome::Gda::Value();
+  }
+
   Gnome::Gda::Value value;
 
   //Check that the user is allowd to view and edit this table:
@@ -1417,14 +1460,7 @@ Gnome::Gda::Value auto_increment_insert_first_if_necessary(const Glib::ustring&
     Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
   builder->select_add_field("next_value", GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME);
   builder->select_add_target(GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME);
-  builder->set_where(
-    builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_AND,
-      builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
-        builder->add_field_id(GLOM_STANDARD_TABLE_AUTOINCREMENTS_FIELD_TABLE_NAME, GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME),
-        builder->add_expr(table_name)),
-      builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
-        builder->add_field_id(GLOM_STANDARD_TABLE_AUTOINCREMENTS_FIELD_FIELD_NAME, GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME),
-        builder->add_expr(field_name))));
+  builder_set_where_autoincrement(builder, table_name, field_name);
 
   const Glib::RefPtr<const Gnome::Gda::DataModel> datamodel = query_execute_select(builder);
   if(!datamodel || (datamodel->get_n_rows() == 0))
@@ -1472,6 +1508,18 @@ Gnome::Gda::Value auto_increment_insert_first_if_necessary(const Glib::ustring&
  */
 static void recalculate_next_auto_increment_value(const Glib::ustring& table_name, const Glib::ustring& field_name)
 {
+  if(table_name.empty())
+  {
+    std::cerr << G_STRFUNC << ": table_name is empty" << std::endl;
+    return;
+  }
+  
+  if(field_name.empty())
+  {
+    std::cerr << G_STRFUNC << ": field_name is empty" << std::endl;
+    return;
+  }
+
   //Make sure that the row exists in the glom system table:
   auto_increment_insert_first_if_necessary(table_name, field_name);
 
@@ -1502,13 +1550,7 @@ static void recalculate_next_auto_increment_value(const Glib::ustring& table_nam
     builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_UPDATE);
     builder->set_table(GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME);
     builder->add_field_value_as_value(GLOM_STANDARD_TABLE_AUTOINCREMENTS_FIELD_NEXT_VALUE, next_value);
-    builder->set_where(builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_AND,
-                                         builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
-                                                           builder->add_field_id(GLOM_STANDARD_TABLE_AUTOINCREMENTS_FIELD_TABLE_NAME, GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME),
-                                                           builder->add_expr(table_name)),
-                                         builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
-                                                           builder->add_field_id(GLOM_STANDARD_TABLE_AUTOINCREMENTS_FIELD_FIELD_NAME, GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME),
-                                                           builder->add_expr(field_name))));
+    builder_set_where_autoincrement(builder, table_name, field_name);
 
     const bool test = query_execute(builder);
     if(!test)
@@ -1518,6 +1560,30 @@ static void recalculate_next_auto_increment_value(const Glib::ustring& table_nam
     std::cerr << "recalculate_next_auto_increment_value(): SELECT MAX() failed." << std::endl;
 }
 
+void remove_auto_increment(const Glib::ustring& table_name, const Glib::ustring& field_name)
+{
+  if(table_name.empty())
+  {
+    std::cerr << G_STRFUNC << ": table_name is empty" << std::endl;
+    return;
+  }
+  
+  if(field_name.empty())
+  {
+    std::cerr << G_STRFUNC << ": field_name is empty" << std::endl;
+    return;
+  }
+  
+  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+    Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_DELETE);
+  builder->set_table(GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME);
+  builder_set_where_autoincrement(builder, table_name, field_name);
+
+  const bool test = query_execute(builder);
+  if(!test)
+    std::cerr << G_STRFUNC << ": UPDATE failed." << std::endl;
+}
+
 bool insert_example_data(Document* document, const Glib::ustring& table_name)
 {
   //TODO_Performance: Avoid copying:
@@ -1803,6 +1869,47 @@ bool query_execute(const Glib::RefPtr<const Gnome::Gda::SqlBuilder>& builder)
   return (exec_retval >= 0);
 }
 
+bool layout_field_should_have_navigation(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& layout_item, const Document* document, sharedptr<Relationship>& field_used_in_relationship_to_one)
+{
+  //Initialize output parameter:
+  field_used_in_relationship_to_one = sharedptr<Relationship>();
+  
+  if(!document)
+  {
+    std::cerr << G_STRFUNC << ": document was null." << std::endl;
+    return false;
+  }
+  
+  if(table_name.empty())
+  {
+    std::cerr << G_STRFUNC << ": table_name was empty." << std::endl;
+    return false;
+  } 
+  
+  if(!layout_item)
+  {
+    std::cerr << G_STRFUNC << ": layout_item was null." << std::endl;
+    return false;
+  }
+
+  //Check whether the field controls a relationship,
+  //meaning it identifies a record in another table.
+  sharedptr<const Relationship> const_relationship =
+    document->get_field_used_in_relationship_to_one(table_name, layout_item);
+  field_used_in_relationship_to_one = sharedptr<Relationship>::cast_const(const_relationship); //This is just because we can't seem to have a sharedptr<const Relationship>& output parameter.
+  // std::cout << "DEBUG: table_name=" << table_name << ", table_used=" << layout_item->get_table_used(table_name) << ", layout_item=" << layout_item->get_name() << ", field_used_in_relationship_to_one=" << field_used_in_relationship_to_one << std::endl;
+
+  //Check whether the field identifies a record in another table
+  //just because it is a primary key in that table:
+  const sharedptr<const Field> field_info = layout_item->get_full_field_details();
+  const bool field_is_related_primary_key =
+    layout_item->get_has_relationship_name() &&
+    field_info && field_info->get_primary_key();
+  // std::cout <<   "DEBUG: layout_item->get_has_relationship_name()=" << layout_item->get_has_relationship_name() << ", field_info->get_primary_key()=" <<  field_info->get_primary_key() << ", field_is_related_primary_key=" << field_is_related_primary_key << std::endl;
+
+  return field_used_in_relationship_to_one || field_is_related_primary_key;
+}
+
 } //namespace DbUtils
 
 } //namespace Glom
