@@ -31,6 +31,11 @@
 #include <libglom/privs.h>
 #include <glom/xsl_utils.h>
 #include <glom/python_embed/glom_python.h>
+
+#include <glom/application.h>
+#include <gtkmm/stock.h>
+#include <gtkmm/viewport.h>
+
 #include <sstream> //For stringstream
 #include <glibmm/i18n.h>
 
@@ -685,22 +690,28 @@ void Box_Data_Details::on_flowtable_field_open_details_requested(const sharedptr
   if(Conversions::value_is_empty(field_value))
     return; //Ignore empty ID fields.
 
+  //Updating doesn't seem necessary. The field details seem to be full already.
+  //Update the field details from the document:
+  ////sharedptr<LayoutItem_Field> unconst_field = sharedptr<LayoutItem_Field>::cast_const(layout_field); //A hack, because layout_field_should_have_navigation() needs to get full field details.
+  //unconst_field->set_full_field_details(
+  //  document->get_field(field->get_table_used(table_name), field->get_name()) ); //Otherwise get_primary_key() returns false always.
+      
+  sharedptr<Relationship> field_used_in_relationship_to_one;
+  const bool has_open_button = 
+    DbUtils::layout_field_should_have_navigation(m_table_name, layout_field, get_document(), 
+    field_used_in_relationship_to_one);
+         
   //If it's a simple field that is part of a relationship,
   //identifying a related record.
-  sharedptr<const Relationship> relationship = get_document()->get_field_used_in_relationship_to_one(m_table_name, layout_field);
-  if(relationship)
+  if(field_used_in_relationship_to_one)
   {
-    signal_requested_related_details().emit(relationship->get_to_table(), field_value);
+    signal_requested_related_details().emit(field_used_in_relationship_to_one->get_to_table(), field_value);
     return;
   }
 
   //If it is a related field that is a primary key,
   //meaning it identifies a record in another table:
-  sharedptr<const Field> field_info = layout_field->get_full_field_details();
-  const bool field_is_related_primary_key =
-    layout_field->get_has_relationship_name() &&
-    field_info && field_info->get_primary_key();
-  if(field_is_related_primary_key)
+  if(has_open_button)
   {
     signal_requested_related_details().emit(layout_field->get_table_used(m_table_name), field_value);
   }
