@@ -21,9 +21,11 @@
 #include <glom/mode_data/box_data_list_related.h>
 #include <glom/mode_design/layout/dialog_layout_list_related.h>
 #include <libglom/data_structure/glomconversions.h>
+#include <libglom/db_utils.h>
 #include <glom/glade_utils.h>
 #include <glom/frame_glom.h> //For show_ok_dialog()
 #include <glom/utils_ui.h> //For bold_message()).
+#include <glibmm/main.h>
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -86,16 +88,11 @@ bool Box_Data_List_Related::init_db_details(const Glib::ustring& parent_table, b
 
   if(show_title)
   {
-    Glib::ustring relationship_title;
-    if(m_portal && m_portal->get_has_relationship_name())
-      relationship_title = m_portal->get_title_used(Glib::ustring() /* parent title - not relevant */);
-    else
-    {
-      //Note to translators: This text is shown instead of a table title, when the table has not yet been chosen.
-      relationship_title = _("Undefined Table");
-    }
-  
-    m_Label.set_markup(Utils::bold_message(relationship_title));
+    Glib::ustring title;
+    if(m_portal)
+      title = m_portal->get_title();
+
+    m_Label.set_markup(Utils::bold_message(title));
     m_Label.show();
 
     m_Alignment.set_padding(Utils::DEFAULT_SPACING_SMALL /* top */, 0, Utils::DEFAULT_SPACING_LARGE /* left */, 0);
@@ -175,14 +172,8 @@ Gnome::Gda::Value Box_Data_List_Related::get_primary_key_value(const Gtk::TreeMo
 
 void Box_Data_List_Related::on_adddel_user_requested_edit(const Gtk::TreeModel::iterator& row)
 {
-  if(!(m_portal->get_relationship_used_allows_edit()))
-  {
-    std::cerr << "Box_Data_List_Related::on_adddel_user_requested_eidt() called on non-editable portal. This should not happen." << std::endl;
-    return;
-  }
+  //Note that this is really an Open rather than an Edit.
 
-  //Call base class:
-  
   const Gnome::Gda::Value primary_key_value = m_AddDel.get_value_key(row); //The primary key is in the key.
   //std::cout << "on_adddel_user_requested_edit(): Requesting edit for primary_key=" << primary_key_value.to_string() << std::endl;
   signal_user_requested_details().emit(primary_key_value);
@@ -465,7 +456,7 @@ void Box_Data_List_Related::create_layout_add_group(const sharedptr<LayoutGroup>
       {
         //Check that the field really exists, to avoid SQL errors.
         //This could probably only happen if we have failed to rename something everywhere, when the user has renamed something.
-        if(!get_field_exists_in_database(child_field->get_table_used(Base_DB_Table::m_table_name), child_field->get_name()))
+        if(!DbUtils::get_field_exists_in_database(child_field->get_table_used(Base_DB_Table::m_table_name), child_field->get_name()))
         {
           std::cerr << "debug: Box_Data_List_Related::create_layout_add_group(): Field does not exist in database: table_name=" << child_field->get_table_used(Base_DB_Table::m_table_name) << ", field_name=" << child_field->get_name() << std::endl;
           continue;
