@@ -197,10 +197,14 @@ void FlowTableWithFields::add_layout_group_at_position(const sharedptr<LayoutGro
 
     if(!group->get_title().empty()) //Don't indent if it has no title, to allow use of groups just for positioning.
     {
-      alignment->set_padding(Glom::Utils::DEFAULT_SPACING_SMALL, 0, 6, 0); //Use left-padding of 6 even on Maemo because indentation is important.
       #ifdef GLOM_ENABLE_MAEMO
       std::cerr << "DEBUG: Unexpected group with title causing extra spacing on Maemo." << std::endl;
       #endif
+
+      //Add some indenting just to avoid the out-denting caused by this GtkFrame bug:
+      //https://bugzilla.gnome.org/show_bug.cgi?id=644199
+      const int BASE_INDENT = 3;
+      alignment->set_padding(Glom::Utils::DEFAULT_SPACING_SMALL, 0, BASE_INDENT, 0);
     }
 
     alignment->show();
@@ -374,13 +378,12 @@ void FlowTableWithFields::add_layout_notebook_at_position(const sharedptr<Layout
       Gtk::Label* tab_label = Gtk::manage(new Gtk::Label());
       tab_label->show();
 #endif
+
+      tab_label->set_label(group->get_title_or_name());
+
       sharedptr<LayoutItem_Portal> portal = sharedptr<LayoutItem_Portal>::cast_dynamic(group);
       if(portal)
       {
-        const Glib::ustring tab_title = glom_get_sharedptr_title_or_name(portal->get_relationship());
-        //tab_label->set_markup(Utils::bold_message(tab_title));
-        tab_label->set_label(tab_title);
-
         //Add a Related Records list for this portal:
         Box_Data_List_Related* portal_box = create_related(portal, false /* no label, because it's in the tab instead. */);
         //portal_box->set_border_width(Glom::Utils::DEFAULT_SPACING_SMALL); It has "padding" around the Alignment instead.
@@ -391,10 +394,6 @@ void FlowTableWithFields::add_layout_notebook_at_position(const sharedptr<Layout
       }
       else
       {
-        const Glib::ustring tab_title = group->get_title_or_name();
-        //tab_label->set_markup(Utils::bold_message(tab_title));
-        tab_label->set_label(tab_title);
-
         //Add a FlowTable for this group:
         FlowTableWithFields* flow_table = Gtk::manage( new FlowTableWithFields() );
         add_view(flow_table); //Allow these sub-flowtables to access the document too.
@@ -837,12 +836,16 @@ void FlowTableWithFields::set_other_field_value(const sharedptr<const LayoutItem
 Gnome::Gda::Value FlowTableWithFields::get_field_value(const sharedptr<const LayoutItem_Field>& field) const
 {
   type_list_const_widgets list_widgets = get_field(field, true);
-  if(!list_widgets.empty())
+  for(type_list_const_widgets::const_iterator iter = list_widgets.begin();
+    iter != list_widgets.end(); ++iter)
   {
-    const DataWidget* datawidget = dynamic_cast<const DataWidget*>(*(list_widgets.begin()));
+    const DataWidget* datawidget = dynamic_cast<const DataWidget*>(*iter);
+    if(!datawidget)
+      continue;
 
-    if(datawidget)
-      return datawidget->get_value();
+    const Gnome::Gda::Value value = datawidget->get_value();
+    if(!Conversions::value_is_empty(value))
+      return value;
   }
 
   //g_warning("FlowTableWithFields::get_field_value(): returning null");
