@@ -18,10 +18,14 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef GLOM_MODE_DESIGN_DIALOG_FIELDDEFINITION_H
-#define GLOM_MODE_DESIGN_DIALOG_FIELDDEFINITION_H
+#ifndef DIALOG_FIELDDEFINITION_H
+#define DIALOG_FIELDDEFINITION_H
 
-#include <gtkmm.h>
+#include <gtkmm/dialog.h>
+#include <gtkmm/checkbutton.h>
+#include <gtkmm/alignment.h>
+#include <gtkmm/entry.h>
+#include <gtkmm/table.h>
 #include "../../utility_widgets/combo_textglade.h"
 #include <glom/mode_design/layout/combobox_relationship.h>
 #include "combo_fieldtype.h"
@@ -100,4 +104,4 @@ private:
 
 } //namespace Glom
 
-#endif // GLOM_MODE_DESIGN_DIALOG_FIELDDEFINITION_H
+#endif //DIALOG_FIELDDEFINITION_H
