@@ -18,13 +18,14 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef GLOM_MODE_DESIGN_DIALOG_LAYOUT_H
-#define GLOM_MODE_DESIGN_DIALOG_LAYOUT_H
+#ifndef GLOM_MODE_DATA_DIALOG_LAYOUT_H
+#define GLOM_MODE_DATA_DIALOG_LAYOUT_H
 
 #include <gtkmm/dialog.h>
 #include <glom/utility_widgets/dialog_properties.h>
 #include <libglom/document/document.h>
 #include <glom/box_withbuttons.h>
+#include <gtkmm/togglebutton.h>
 
 namespace Glom
 {
@@ -77,4 +78,4 @@ protected:
 
 } //namespace Glom
 
-#endif // GLOM_MODE_DESIGN_DIALOG_LAYOUT_H
+#endif //GLOM_MODE_DATA_DIALOG_LAYOUT_H
