@@ -33,6 +33,9 @@
 #include <gtkmm/uimanager.h>
 //TODO: #include <gtkmm/ruler.h>
 #include <glom/utility_widgets/gimpruler/gimpruler.h>
+#include <gtkmm/scrolledwindow.h>
+#include <gtkmm/spinbutton.h>
+#include <gtkmm/button.h>
 #include <gtkmm/builder.h>
 
 namespace Glom
