@@ -28,6 +28,9 @@
 #include <libglom/data_structure/layout/report_parts/layoutitem_footer.h>
 #include <libglom/db_utils.h>
 #include <glom/xsl_utils.h>
+#include <iostream>
+#include <glibmm/miscutils.h>
+#include <glibmm/i18n.h>
 
 namespace Glom
 {
@@ -188,7 +191,7 @@ void ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp
       builder->set_where( builder->import_expression(found_set_parent.m_where_clause) );
     }
 
-    builder->select_group_by( builder->add_id(field_group_by->get_name()) ); //TODO: And restrict to the current found set.
+    builder->select_group_by( builder->add_field_id(field_group_by->get_name(), group_field_table_name) ); //TODO: And restrict to the current found set.
 
     Glib::RefPtr<Gnome::Gda::DataModel> datamodel = DbUtils::query_execute_select(builder);
     if(datamodel)
