@@ -18,13 +18,16 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef GLOM_UTLITY_WIDGETS_ADDDEL_H
-#define GLOM_UTLITY_WIDGETS_ADDDEL_H
+#ifndef ADDDEL_H
+#define ADDDEL_H
 
-#include <gtkmm.h>
 #include <libglom/data_structure/field.h>
-#include <libgdamm.h>
 #include <gtkmm/builder.h>
+#include <gtkmm/treeview.h>
+#include <gtkmm/scrolledwindow.h>
+#include <gtkmm/box.h>
+#include <gtkmm/liststore.h>
+#include <gtkmm/uimanager.h>
 
 #include <vector>
 #include <map>
@@ -330,4 +333,4 @@ guint AddDel::treeview_append_column(const Glib::ustring& title, const Gtk::Tree
 } //namespace Glom
 
 
-#endif // GLOM_UTLITY_WIDGETS_ADDDEL_H
+#endif //ADDDEL_H
