@@ -22,6 +22,7 @@
 #define ADDDEL_WITHBUTTONS_H
 
 #include "adddel.h"
+#include <gtkmm/buttonbox.h>
 
 namespace Glom
 {
@@ -30,7 +31,7 @@ class AddDel_WithButtons : public AddDel
 {
 public: 
   AddDel_WithButtons();
-  AddDel_WithButtons(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  AddDel_WithButtons(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~AddDel_WithButtons();
 
   virtual void set_allow_add(bool val = true); //override
@@ -46,7 +47,7 @@ private:
   void on_button_edit();
 
   //member widgets:
-  Gtk::HBox m_HBox;
+  Gtk::HButtonBox m_ButtonBox;
   Gtk::Button m_Button_Add;
   Gtk::Button m_Button_Del;
   Gtk::Button m_Button_Edit;
