@@ -30,6 +30,8 @@
 #include "cellrenderer_buttonimage.h"
 #include "cellrenderer_buttontext.h"
 #include <glom/utils_ui.h> //For Utils::image_scale_keeping_ratio().
+#include <gtkmm/stock.h>
+#include <glibmm/main.h>
 #include <libglom/db_utils.h>
 
 #include <iostream> //For debug output.
@@ -2193,8 +2195,8 @@ guint DbAddDel::treeview_append_column(const Glib::ustring& title, Gtk::CellRend
       //TODO: Choose a width based on the first 100 values.
       if(layout_item_field)
       {
-       column_width = Utils::get_suitable_field_width_for_widget(*this, layout_item_field, true /* or_title */);
-       column_width = column_width / 3;
+       column_width = Utils::get_suitable_field_width_for_widget(*this, layout_item_field, true /* or_title */, true /* for treeview */);
+       column_width = column_width + 8; //Some extra for the GtkTreeView's padding.
        //std::cout << "DEBUG: column_width=" << column_width << std::endl;
       }
       else
